# Whenever this version string changes, the application is configured
# and rebuilt from scratch
VERSION = supermuc-impi-2019-05-16

### ATTENTION:
### In order to build with this optionlist, you MUST have loaded a recent GCC.
###   $ module load gcc/6
### Otherwise, compilation will likely fail with strange "hwloc" errors.

# Use default compiler loaded at login:
# module show intel
CPP = cpp
FPP = cpp
CC  = gcc 
CXX = g++
F90 = gfortran
F77 = gfortran

CPPFLAGS = -DMPICH_IGNORE_CXX_SEEK # -DCCTK_DISABLE_RESTRICT
FPPFLAGS = -traditional
CFLAGS   = -g -std=gnu99  -U__STRICT_ANSI__
CXXFLAGS = -g -std=gnu++17
F77FLAGS = -g -march=native -fcray-pointer -ffixed-line-length-none -fno-range-check # -fno-underscoring 
F90FLAGS = -g -march=native -fcray-pointer -ffixed-line-length-none -fno-range-check # -fno-underscoring 

LDFLAGS = -rdynamic

LIBDIRS = /dss/dsshome1/0D/di39rof2/libnuma:/lrz/sys/intel/studio2019_u3/compilers_and_libraries_2019.3.199/linux/compiler/lib/intel64:/lrz/sys/intel/studio2019_u3/compilers_and_libraries_2019.3.199/linux/compiler/lib/intel64_lin
LIBS    = ifcore numa

C_LINE_DIRECTIVES = yes
F_LINE_DIRECTIVES = yes

#VECTORISE                = yes
#VECTORISE_ALIGNED_ARRAYS = no
#VECTORISE_INLINE         = no

DEBUG = no
CPP_DEBUG_FLAGS = -DCARPET_DEBUG
FPP_DEBUG_FLAGS = -DCARPET_DEBUG
C_DEBUG_FLAGS   = -O0
CXX_DEBUG_FLAGS = -O0
F77_DEBUG_FLAGS = -O0
F90_DEBUG_FLAGS = -O0

OPTIMISE = yes
CPP_OPTIMISE_FLAGS = # -DCARPET_OPTIMISE -DNDEBUG
FPP_OPTIMISE_FLAGS = # -DCARPET_OPTIMISE -DNDEBUG
C_OPTIMISE_FLAGS   = -O2 -funroll-loops
CXX_OPTIMISE_FLAGS = -O2 -funroll-loops
F77_OPTIMISE_FLAGS = -O2 -funroll-loops
F90_OPTIMISE_FLAGS = -O2 -funroll-loops

C_NO_OPTIMISE_FLAGS    = -O0
CXX_NO_OPTIMISE_FLAGS  = -O0
F77_NO_OPTIMISE_FLAGS  = -O0
F90_NO_OPTIMISE_FLAGS  = -O0

PROFILE = no
CPP_PROFILE_FLAGS =
FPP_PROFILE_FLAGS =
C_PROFILE_FLAGS   = -pg
CXX_PROFILE_FLAGS = -pg
F77_PROFILE_FLAGS = -pg
F90_PROFILE_FLAGS = -pg

OPENMP           = yes
CPP_OPENMP_FLAGS = -fopenmp #-D_OPENMP
FPP_OPENMP_FLAGS = -fopenmp #-D_OPENMP
C_OPENMP_FLAGS   = -fopenmp
CXX_OPENMP_FLAGS = -fopenmp
F77_OPENMP_FLAGS = -fopenmp
F90_OPENMP_FLAGS = -fopenmp

WARN           = yes
CPP_WARN_FLAGS = -Wall
FPP_WARN_FLAGS = -Wall
C_WARN_FLAGS   = -Wall
CXX_WARN_FLAGS = -Wall
F77_WARN_FLAGS = -Wall
F90_WARN_FLAGS = -Wall

# module show mkl:
BLAS_DIR  = /lrz/sys/intel/studio2019_u3/compilers_and_libraries_2019.3.199/linux/mkl/lib/intel64
BLAS_LIBS = -Wl,--start-group  mkl_intel_lp64 mkl_intel_thread mkl_core -Wl,--end-group mkl_blas95_lp64  iomp5  pthread m

# module show boost/1.61_gcc
BOOST_DIR = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/boost/1.68.0-gcc-twmbcv6
BOOST_LIBS  = boost_system boost_filesystem

# module show fftw
FFTW3_DIR = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/fftw/3.3.8-gcc-a3vxevk
FFTW3_LIBS = fftw3f fftw3 fftw3l m

# module show gsl
GSL_DIR = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/gsl/2.5-gcc-loelpwi

# module show hdf5
# It might be missing -lgpfs when the linking is static.
# Investigate if it matters at all. Ask help desk otherwise.
#HDF5_DIR  = /lrz/sys/libraries/hdf5/1.8.15/serial_icc_16.0
#/dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/hdf5/1.10.2-intel-ze5274l/
HDF5_DIR  = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/hdf5/1.10.2-gcc-kzxp6ch
#HDF5_DIR  = BUILD
LIBSZ_DIR = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/libszip/2.1.1-gcc-v3th2mi #/lrz/sys/libraries/hdf5/szip_2.1_u1/lib
ZLIB_DIR  = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/zlib/1.2.11-gcc-ajxhsmr
# Introduce later to HDF5 thorn the environment variable
# for extra HDF5 libraries the system library might be linked to:
# HDF5_EXTRA_LIBS = sz z rt dl m gpfs


#module show hwloc
HWLOC_DIR = /lrz/sys/tools/hwloc/1.11.7

LAPACK_DIR  = /lrz/sys/intel/studio2019_u3/compilers_and_libraries_2019.3.199/linux/mkl/lib/intel64
#LAPACK_LIBS =  mkl_intel_lp64 mkl_lapack95_lp64 mkl_intel_thread mkl_core  iomp5  pthread m
LAPACK_LIBS =  mkl_lapack95_lp64

# Don't include mpi++ in MPI_LIBS; this makes it impossible to build
# utilities written in Fortran
# module show mpi.ibm
#MPI_DIR      = /lrz/sys/intel/studio2019_u3/impi/2019.3.199/intel64
#MPI_INC_DIRS = /lrz/sys/intel/studio2019_u3/impi/2019.3.199/intel64/include
#MPI_LIB_DIRS = /lrz/sys/intel/studio2019_u3/impi/2019.3.199/intel64/lib/release /lrz/sys/intel/studio2019_u3/impi/2019.3.199/intel64/lib
#MPI_LIBS     = mpicxx mpifort mpi dl rt pthread

# module show papi
#PAPI_DIR  = /lrz/sys/tools/papi/5.6/skl

# module show petsc
PETSC_DIR          = /dss/dsshome1/lrz/sys/spack/release/19.1/opt/x86_avx512/petsc/3.10.2-gcc-j3lfg22
#PETSC_ARCH         =
PETSC_ARCH_LIBS    = mkl_blas95_lp64 mkl_intel_lp64 mkl_intel_thread mkl_core iomp5 pthread m  X11

KADATH_DIR = /dss/dsshome1/0C/*****/lib/Kadath
